@@ -10,5 +10,5 @@ class Test(TestCase):
 
     def test_1(self):
         self.chord.add_midi(60)
-        steps = [step.value for note in self.chord._notes for pitch in note.get_children_by_type(Pitch) for step in pitch.get_children_by_type(Step)]
+        steps = [step.value for note in self.chord.notes for pitch in note.get_children_by_type(Pitch) for step in pitch.get_children_by_type(Step)]
         self.assertEqual(steps, ['B', 'C'])
